From 0781e12a5583d55729923b9cea2061551c261ab1 Mon Sep 17 00:00:00 2001
From: Francois-Rene Rideau <fare@tunes.org>
Date: Tue, 26 Apr 2011 13:06:12 -0400
Subject: [PATCH] 2.014.12: Don't be so verbose when you're verbose. Use
 :verbose nil in REQUIRE anyway. Make meaning of operation-description less
 unobvious.

---
 asdf.asd  |  2 +-
 asdf.lisp | 33 +++++++++++++++++++++++++--------
 2 files changed, 26 insertions(+), 9 deletions(-)

diff --git a/asdf.asd b/asdf.asd
index 1504566e..1a69942a 100644
--- a/asdf.asd
+++ b/asdf.asd
@@ -12,7 +12,7 @@
   :licence "MIT"
   :description "Another System Definition Facility"
   :long-description "ASDF builds Common Lisp software organized into defined systems."
-  :version "2.014.11" ;; to be automatically updated by bin/bump-revision
+  :version "2.014.12" ;; to be automatically updated by bin/bump-revision
   :depends-on ()
   :components
   ((:file "asdf")
diff --git a/asdf.lisp b/asdf.lisp
index 7254408d..573a7600 100755
--- a/asdf.lisp
+++ b/asdf.lisp
@@ -1,5 +1,5 @@
 ;; -*- mode: common-lisp; Base: 10 ; Syntax: ANSI-Common-Lisp -*-
 ;;; This is ASDF 2.014.11: Another System Definition Facility.
 ;;;
 ;;; Feedback, bug reports, and patches are all welcome:
 ;;; please mail to <asdf-devel@common-lisp.net>.
@@ -100,7 +100,7 @@
          ;; "2.345.6" would be a development version in the official upstream
          ;; "2.345.0.7" would be your seventh local modification of official release 2.345
          ;; "2.345.6.7" would be your seventh local modification of development version 2.345.6
-         (asdf-version "2.014.11")
+         (asdf-version "2.014.12")
          (existing-asdf (fboundp 'find-system))
          (existing-version *asdf-version*)
          (already-there (equal asdf-version existing-version)))
@@ -982,7 +982,7 @@ processed in order by OPERATE."))
       '(defmethod update-instance-for-redefined-class :after
            ((m module) added deleted plist &key)
          (declare (ignorable deleted plist))
-         (when (or *asdf-verbose* *load-verbose*)
+         (when *asdf-verbose*
            (asdf-message (compatfmt "~&~@<; ~@;Updating ~A for ASDF ~A~@:>~%")
 			 m (asdf-version)))
          (when (member 'components-by-name added)
@@ -2108,7 +2108,12 @@ recursive calls to traverse.")
 
 (defmethod operation-description ((operation compile-op) component)
   (declare (ignorable operation))
-  (format nil "compiling ~A" component))
+  (format nil (compatfmt "~@<compiling ~3i~_~A~@:>") component))
+
+(defmethod operation-description ((operation compile-op) (component module))
+  (declare (ignorable operation))
+  (format nil (compatfmt "~@<compiled ~3i~_~A~@:>") component))
+
 
 ;;;; -------------------------------------------------------------------------
 ;;;; load-op
@@ -2121,8 +2126,7 @@ recursive calls to traverse.")
   (map () #'load (input-files o c)))
 
 (defmethod perform-with-restarts (operation component)
-  (when *asdf-verbose*
-    (explain operation component))
+  ;;(when *asdf-verbose* (explain operation component)) ; TOO verbose, especially as the default.
   (perform operation component))
 
 (defmethod perform-with-restarts ((o load-op) (c cl-source-file))
@@ -2185,9 +2189,18 @@ recursive calls to traverse.")
 
 (defmethod operation-description ((operation load-op) component)
   (declare (ignorable operation))
-  (format nil (compatfmt "~@<Loading ~3i~_~A~@:>")
+  (format nil (compatfmt "~@<loading ~3i~_~A~@:>")
+	  component))
+
+(defmethod operation-description ((operation load-op) (component cl-source-file))
+  (declare (ignorable operation))
+  (format nil (compatfmt "~@<loading FASL for ~3i~_~A~@:>")
 	  component))
 
+(defmethod operation-description ((operation load-op) (component module))
+  (declare (ignorable operation))
+  (format nil (compatfmt "~@<loaded ~3i~_~A~@:>")
+	  component))
 
 ;;;; -------------------------------------------------------------------------
 ;;;; load-source-op
@@ -2232,6 +2245,10 @@ recursive calls to traverse.")
   (format nil (compatfmt "~@<Loading source of ~3i~_~A~@:>")
 	  component))
 
+(defmethod operation-description ((operation load-source-op) (component module))
+  (declare (ignorable operation))
+  (format nil (compatfmt "~@<Loaded source of ~3i~_~A~@:>") component))
+
 
 ;;;; -------------------------------------------------------------------------
 ;;;; test-op
@@ -3965,7 +3982,7 @@ with a different configuration, so the configuration would be re-read then."
     (let ((*verbose-out* (make-broadcast-stream))
            (system (find-system (string-downcase name) nil)))
       (when system
-        (operate *require-asdf-operator* system)
+        (operate *require-asdf-operator* system :verbose nil)
         t))))
 
 #+(or abcl clisp clozure cmu ecl sbcl)
@@ -1,5 +1,5 @@
 ;; -*- mode: common-lisp; Base: 10 ; Syntax: ANSI-Common-Lisp -*-
-;;; This is ASDF 2.014.11: Another System Definition Facility.
+;;; This is ASDF 2.014.12: Another System Definition Facility.
 ;;;
 ;;; Feedback, bug reports, and patches are all welcome:
-- 
GitLab